BoundsExceeded

Struct BoundsExceeded 

pub struct BoundsExceeded;
Available on (crate features alloc or std or derive or serde or zero-copy or static-size) and crate feature static-size and crate feature alloc only.
Error returned when a value exceeds a bounded type’s capacity.