BitReader

Struct BitReader 

pub struct BitReader<'a, R: Reader> { /* private fields */ }
A wrapper around a Reader that allows reading data bit-by-bit.

Implementations

Source

impl<'a, R: Reader> BitReader<'a, R>

pub const fn new(reader: &'a mut R) -> Self

Creates a new BitReader.

pub const fn from_state( reader: &'a mut R, current_byte: u8, bits_available: u8, ) -> Self

Creates a new BitReader with an existing state.

pub const fn get_state(&self) -> (u8, u8)

Returns the current state of the bit reader (current_byte, bits_available).

pub fn read_bits_lsb(&mut self, num_bits: u8) -> Result<u64, DecodeError>

Reads num_bits from the stream, using LSB-first bit ordering.

Errors

Returns DecodeError if the underlying reader fails to provide enough bytes.

pub fn read_bits_msb(&mut self, num_bits: u8) -> Result<u64, DecodeError>

Reads num_bits from the stream, using MSB-first bit ordering.

Errors

Returns DecodeError if the underlying reader fails to provide enough bytes.

pub fn read_bits<C: Config>( &mut self, num_bits: u8, config: &C, ) -> Result<u64, DecodeError>

Reads num_bits from the stream, using the bit ordering from the configuration.

Errors

Returns DecodeError if the underlying reader fails to provide enough bytes.

pub const fn align_to_byte(&mut self)

Discards any remaining unread bits in the current byte, effectively returning to byte alignment.