DecoderImpl

Struct DecoderImpl 

pub struct DecoderImpl<R, C: Config, Context> { /* private fields */ }
A Decoder that reads bytes from a given reader R.

This struct should rarely be used. In most cases, prefer any of the decode functions.

The ByteOrder that is chosen will impact the endianness that is used to read integers out of the reader.

use bincode_next::de::Decode;
use bincode_next::de::DecoderImpl;
let mut context = ();
let mut decoder = DecoderImpl::new(some_reader, bincode_next::config::standard(), &mut context);
// this u32 can be any Decode
let value = u32::decode(&mut decoder).unwrap();

Implementations

Source

impl<R: Reader, C: Config, Context> DecoderImpl<R, C, Context>

pub const fn new(reader: R, config: C, context: Context) -> Self

Construct a new Decoder