pub struct SizeWriter {
pub bytes_written: usize,
}Expand description
A writer that counts how many bytes were written. This is useful for e.g. pre-allocating buffers before writing to them.
Fields
bytes_written: usizethe amount of bytes that were written so far