pub async fn decode_async<T, R, C>(
config: C,
reader: R,
) -> Result<T, DecodeError>Available on crate feature
async-fiber only.Expand description
Attempt to decode a given type T from the given async reader safely using a non-blocking fiber.
Requires the async-fiber feature.
Errors
Returns a DecodeError if the reader fails or the data is invalid.