decode_async_std

Function decode_async_std 

pub async fn decode_async_std<T, R, C>(
    config: C,
    reader: R,
) -> Result<T, DecodeError>
where T: Decode<()>, R: AsyncRead + Unpin, C: Config, C::Mode: InternalFingerprintGuard<T, C>,
Available on crate feature async-fiber only.
Attempt to decode a given type T from an async-std reader.

Requires the async-fiber feature.

Errors

Returns a DecodeError if the reader fails or the data is invalid.