pub async fn decode_async_with_context<T, R, C, Context>(
config: C,
reader: R,
context: Context,
) -> Result<T, DecodeError>Available on crate feature
async-fiber only.Expand description
Attempt to decode a given type T from the given async reader using a non-blocking fiber and a context.
This is the primary implementation for runtimes that use the futures-io traits (e.g. async-std, smol).
Requires the async-fiber feature.
Errors
Returns a DecodeError if the reader fails or the data is invalid.