ZeroSlice

Struct ZeroSlice 

pub struct ZeroSlice<T, const ALIGN: usize, E: Endian = NativeEndian> { /* private fields */ }
Available on (crate features alloc or std or derive or serde or zero-copy or static-size) and crate feature zero-copy only.
A zero-copy slice collection conceptually equivalent to &[T] or Vec<T>.

Implementations

Source

impl<T: ZeroCopy, const ALIGN: usize, E: Endian> ZeroSlice<T, ALIGN, E>

pub fn new(len: u32, offset: i32) -> Self

Creates a new ZeroSlice with the given native length and relative offset.

pub fn get<'a>(&self, buffer: &'a [u8]) -> Option<&'a [T]>

Resolves the slice within the given buffer.