#[non_exhaustive]pub enum DecodeError {
AnyNotSupported,
IdentifierNotSupported,
IgnoredAnyNotSupported,
CannotBorrowOwnedData,
}Available on crate feature
serde only.Expand description
A serde-specific error that occurred while decoding.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
AnyNotSupported
Bincode does not support serde’s any decoding feature.
See the “known issues” list in the serde module for more information on this.
IdentifierNotSupported
Bincode does not support serde identifiers
IgnoredAnyNotSupported
Bincode does not support serde’s ignored_any.
See the “known issues” list in the serde module for more information on this.
CannotBorrowOwnedData
Serde tried decoding a borrowed value from an owned reader. Use serde_decode_borrowed_from_* instead