Module static_size

Module static_size 

Available on crate feature static-size and (crate features alloc or derive or serde or static-size or std or zero-copy) only.
Static size trait for compile-time memory bound validation.

Traits

StaticSize
A trait that calculates the upper bound of a type’s serialized size as a const value.