pub trait Config:
InternalEndianConfig
+ InternalIntEncodingConfig
+ InternalLimitConfig
+ InternalBitPackingConfig
+ InternalBitOrderingConfig
+ InternalFingerprintConfig
+ InternalFormatConfig
+ InternalConfigFingerprint
+ InternalFingerprintConfigExt
+ Copy
+ Clone {
// Required methods
fn endianness(&self) -> Endianness;
fn int_encoding(&self) -> IntEncoding;
fn limit(&self) -> Option<usize>;
fn bit_packing_enabled(&self) -> bool;
fn bit_ordering(&self) -> BitOrdering;
fn fingerprint_mode(&self) -> FingerprintMode;
fn format(&self) -> Format;
fn cbor_options(&self) -> CborOptions;
fn is_compact_net(&self) -> bool;
}Expand description
Indicates a type is valid for controlling the bincode configuration
Required Methods
Sourcefn endianness(&self) -> Endianness
fn endianness(&self) -> Endianness
This configuration’s Endianness
Sourcefn int_encoding(&self) -> IntEncoding
fn int_encoding(&self) -> IntEncoding
This configuration’s Integer Encoding
Sourcefn limit(&self) -> Option<usize>
fn limit(&self) -> Option<usize>
This configuration’s byte limit, or None if no limit is configured
Sourcefn bit_packing_enabled(&self) -> bool
fn bit_packing_enabled(&self) -> bool
Whether bit-packing is enabled for this configuration
Sourcefn bit_ordering(&self) -> BitOrdering
fn bit_ordering(&self) -> BitOrdering
Returns the bit ordering of this configuration
Sourcefn fingerprint_mode(&self) -> FingerprintMode
fn fingerprint_mode(&self) -> FingerprintMode
Returns the fingerprint mode of this configuration
Sourcefn cbor_options(&self) -> CborOptions
fn cbor_options(&self) -> CborOptions
Returns the CBOR options of this configuration. Returns default options if the format is not CBOR.
Sourcefn is_compact_net(&self) -> bool
fn is_compact_net(&self) -> bool
Returns true if this configuration uses compact network encoding (omitting flowinfo/scope_id).
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".