pub struct BitWriter<'a, W: Writer> { /* private fields */ }Expand description
A wrapper around a Writer that allows writing data bit-by-bit.
Implementations
Sourceimpl<'a, W: Writer> BitWriter<'a, W>
impl<'a, W: Writer> BitWriter<'a, W>
Sourcepub const fn from_state(
writer: &'a mut W,
current_byte: u8,
bit_count: u8,
) -> Self
pub const fn from_state( writer: &'a mut W, current_byte: u8, bit_count: u8, ) -> Self
Creates a new BitWriter with an existing state.
Sourcepub const fn get_state(&self) -> (u8, u8)
pub const fn get_state(&self) -> (u8, u8)
Returns the current state of the bit writer (current_byte, bit_count).
Sourcepub fn write_bits_lsb(
&mut self,
val: u64,
num_bits: u8,
) -> Result<(), EncodeError>
pub fn write_bits_lsb( &mut self, val: u64, num_bits: u8, ) -> Result<(), EncodeError>
Writes num_bits from val into the stream, using LSB-first bit ordering.
Errors
Returns EncodeError if the underlying writer fails to write the data.
Sourcepub fn write_bits_msb(
&mut self,
val: u64,
num_bits: u8,
) -> Result<(), EncodeError>
pub fn write_bits_msb( &mut self, val: u64, num_bits: u8, ) -> Result<(), EncodeError>
Writes num_bits from val into the stream, using MSB-first bit ordering.
Errors
Returns EncodeError if the underlying writer fails to write the data.
Sourcepub fn write_bits<C: Config>(
&mut self,
val: u64,
num_bits: u8,
config: &C,
) -> Result<(), EncodeError>
pub fn write_bits<C: Config>( &mut self, val: u64, num_bits: u8, config: &C, ) -> Result<(), EncodeError>
Writes num_bits from val into the stream, using the bit ordering from the configuration.
Errors
Returns EncodeError if the underlying writer fails to write the data.