pub struct RelativePtr<T, const ALIGN: usize, E: Endian = NativeEndian> { /* private fields */ }Available on (crate features
alloc or std or derive or serde or zero-copy or static-size) and crate feature zero-copy only.Expand description
A relative pointer that stores the offset from its own address to the target data. This allows zero-copy deserialization without runtime allocations.
Implementations
Sourceimpl<T, const ALIGN: usize, E: Endian> RelativePtr<T, ALIGN, E>
impl<T, const ALIGN: usize, E: Endian> RelativePtr<T, ALIGN, E>