Available on crate feature
static-size and (crate features alloc or derive or serde or static-size or std or zero-copy) only.Expand description
Static size trait for compile-time memory bound validation.
Traits
- Static
Size - A trait that calculates the upper bound of a type’s serialized size as a
constvalue.