Available on crate feature
zero-copy only.Expand description
Relative pointer system for zero-copy nested structures
Structs
- Relative
Ptr - A relative pointer that stores the offset from its own address to the target data. This allows zero-copy deserialization without runtime allocations.
- Zero
Array - A zero-copy array collection equivalent to
[T; N]. - Zero
Builder alloc - A builder for zero-copy structures.
- Zero
Slice - A zero-copy slice collection conceptually equivalent to
&[T]orVec<T>. - ZeroStr
- A dynamically sized zero-copy string conceptually equivalent to
&strorString. - Zero
String - A zero-copy string type with compile-time known max capacity, stored inline.
Traits
- Deep
Validator - A trait for deep validation of zero-copy structures, recursively checking all pointers.
- Static
Size - Indicates that a type has a fixed size known at compile time. This allows us to perform bounds checking efficiently.
- Validator
- A trait for validating zero-copy types.
- Zero
Copy - A marker trait indicating that a type has a fixed, predictable layout (e.g.,
#[repr(C)]) and contains no padding bytes or invalid bit patterns allowing safe zero-copy casting. - Zero
Copy Builder - A trait for types that can be built into a zero-copy structure.
- Zero
Copy Type - A trait for zero-copy types that defines their preferred builder type.