Trait Validator
Source pub trait Validator {
// Required method
fn is_valid(&self, buffer: &[u8]) -> bool;
}
Available on crate feature zero-copy only.
A trait for validating zero-copy types.
Checks if the relative pointer is valid within the given buffer.
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Checks if the relative pointer is valid within the given buffer.
Checks if the relative pointer is valid within the given buffer.
Checks if the relative pointer is valid within the given buffer.
Checks if the relative pointer is valid within the given buffer.
Checks if the relative pointer is valid within the given buffer.
Checks if the relative pointer is valid within the given buffer.
Checks if the relative pointer is valid within the given buffer.
Checks if the relative pointer is valid within the given buffer.
Checks if the relative pointer is valid within the given buffer.
Checks if the relative pointer is valid within the given buffer.
Checks if the relative pointer is valid within the given buffer.
Checks if the relative pointer is valid within the given buffer.
Checks if the relative pointer is valid within the given buffer.
Checks if the relative pointer is valid within the given buffer.
Checks if the relative pointer is valid within the given buffer.
Checks if the relative pointer is valid within the given buffer.
Checks if the relative pointer is valid within the given buffer.